<!-- verocase package C1 -->
<!-- end verocase -->

<!-- verocase element C1 -->
<!-- end verocase -->

<!-- verocase statement C1 -->
Statement: The software is acceptably safe
<!-- end verocase -->

<!-- verocase sacm/mermaid C1 -->
```mermaid
stale content
```
<!-- end verocase -->
